<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>Application</name>
    <message>
        <location filename="../../src/apps/dde-cooperation/main.cpp" line="50"/>
        <source>Cooperation</source>
        <translation>跨端协同</translation>
    </message>
    <message>
        <location filename="../../src/apps/dde-cooperation/main.cpp" line="54"/>
        <source>Cooperation is a powerful cross-terminal office tool that helps you deliver files, share keys and mice, and share clipboards between different devices.</source>
        <translation>跨端协同是一款强大的跨终端办公工具，可帮助您在不同设备之间实现文件投送、共享键鼠、共享剪贴板。</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/cooperationplugin.cpp" line="69"/>
        <source>File transfer settings</source>
        <translation>文件投送设置</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/cooperationplugin.cpp" line="71"/>
        <source>Settings</source>
        <comment>button</comment>
        <translation>设置</translation>
    </message>
</context>
<context>
    <name>cooperation_core::BottomLabel</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="341"/>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="373"/>
        <source>Local IP: %1</source>
        <translation>本机IP：%1</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ConfirmWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="25"/>
        <source>&quot;%1&quot; send some files to you</source>
        <translation>“%1”向你发送一封文件</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="34"/>
        <source>Reject</source>
        <comment>button</comment>
        <translation>拒绝</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="35"/>
        <source>Accept</source>
        <comment>button</comment>
        <translation>接受</translation>
    </message>
</context>
<context>
    <name>cooperation_core::CooperationSearchEdit</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/win/cooperationsearchedit.cpp" line="34"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
</context>
<context>
    <name>cooperation_core::CooperationTaskDialog</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="111"/>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="131"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="134"/>
        <source>Retry</source>
        <comment>button</comment>
        <translation>重试</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="157"/>
        <source>Reject</source>
        <comment>button</comment>
        <translation>拒绝</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="160"/>
        <source>Accept</source>
        <comment>button</comment>
        <translation>接受</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="184"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>关闭</translation>
    </message>
</context>
<context>
    <name>cooperation_core::CooperationTransDialog</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="275"/>
        <source>File Transfer</source>
        <translation>文件投送</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="278"/>
        <source>File transfer</source>
        <translation>文件投送</translation>
    </message>
</context>
<context>
    <name>cooperation_core::CooperationUtil</name>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="217"/>
        <source>View Help Manual</source>
        <translation>查看帮助手册</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="218"/>
        <source>Welcome to dde-cooperation</source>
        <translation>欢迎使用跨端协同</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="222"/>
        <source>Keyboard and mouse sharing</source>
        <translation>键鼠共享</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="222"/>
        <source>When a connection is made between two devices, the initiator&apos;s keyboard and mouse can be used to control the other device</source>
        <translation>两台设备间进行连接后，可使用发起方的键鼠控制另一设备</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="224"/>
        <source>Clipboard sharing</source>
        <translation>剪贴板共享</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="224"/>
        <source>Once a connection is made between two devices, the clipboard will be shared and can be copied on one device and pasted on the other device</source>
        <translation>两台设备间进行连接后，将共享剪贴板，可在一台设备上复制，另一台设备粘贴</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="226"/>
        <source>Delivery of documents</source>
        <translation>文件投送</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="226"/>
        <source>After connecting between two devices, you can initiate a file delivery to the other device</source>
        <translation>两台设备间进行连接后，可向对方设备发起文件投送</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="228"/>
        <source>For detailed instructions, please click on the Help Manual below</source>
        <translation>详细的使用方法，请点击下方《帮助手册》进行查看</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="228"/>
        <source>Usage</source>
        <translation>使用方法</translation>
    </message>
</context>
<context>
    <name>cooperation_core::DeviceItem</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/deviceitem.cpp" line="191"/>
        <source>connected</source>
        <translation>协同中</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/deviceitem.cpp" line="197"/>
        <source>connectable</source>
        <translation>可连</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/deviceitem.cpp" line="204"/>
        <source>offline</source>
        <translation>离线</translation>
    </message>
</context>
<context>
    <name>cooperation_core::DiscoverController</name>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="245"/>
        <source>Confirm</source>
        <translation>确认</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="246"/>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="248"/>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="257"/>
        <source>Please click to confirm to enable the LAN discovery service!</source>
        <translation>请单击确认以启用局域网发现服务！</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="249"/>
        <source>Unable to discover and be discovered by other devices when LAN discovery service is not turned on</source>
        <translation>未开启局域网发现服务时，无法发现其他设备，也无法被其他设备发现</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="258"/>
        <source>Unable to discover and be discovered by other devices when LAN discovery service is not turned onRight click on Windows Start menu -&gt;Computer Management -&gt;Services and Applications -&gt;Services to enable Bonjour service</source>
        <translation>未打开局域网发现服务时，无法发现其他设备或被其他设备发现，右键单击 Windows 开始菜单 -&gt; 计算机管理 -&gt; 服务和应用程序 -&gt; 服务，启用 Bonjour 服务</translation>
    </message>
</context>
<context>
    <name>cooperation_core::FirstTipWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="126"/>
        <source>First step</source>
        <translation>第1步</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="127"/>
        <source>The opposite end opens the application and connects to the same network</source>
        <translation>对端开启应用，并连接同一网络</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="128"/>
        <source>Second step</source>
        <translation>第2步</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="130"/>
        <source>Third step</source>
        <translation>第3步</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="189"/>
        <source>to send the file</source>
        <translation>发送文件</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="196"/>
        <source>to connect to the peer device</source>
        <translation>连接对端设备</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="129"/>
        <source>Enter the peer IP in the search box</source>
        <translation>在搜索框输入对端IP</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="131"/>
        <source>Click</source>
        <translation>点击</translation>
    </message>
</context>
<context>
    <name>cooperation_core::InformationDialog</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="153"/>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="158"/>
        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="166"/>
        <source>the file save location is invalid</source>
        <translation>文件保存位置无效</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="172"/>
        <source>This path is a read-only directory. Please choose a different location for saving the file.</source>
        <translation>此路径为只读目录，请更换文件保存位置。</translation>
    </message>
</context>
<context>
    <name>cooperation_core::LockScreenWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/screenmirroringwindow.cpp" line="204"/>
        <source>The current device has been locked</source>
        <translation>当前设备已被锁定</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/screenmirroringwindow.cpp" line="207"/>
        <source>You can unlock it on mobile devices</source>
        <translation>你可以在移动端解锁</translation>
    </message>
</context>
<context>
    <name>cooperation_core::LookingForDeviceWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="81"/>
        <source>Looking for devices</source>
        <translation>正在寻找设备</translation>
    </message>
</context>
<context>
    <name>cooperation_core::MainWindow</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="266"/>
        <source>Minimise to system tray</source>
        <translation>最小化到系统托盘</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="268"/>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="277"/>
        <source>No more enquiries</source>
        <translation>不再询问</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="285"/>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="296"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="286"/>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="295"/>
        <source>Confirm</source>
        <translation>确认</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="287"/>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="294"/>
        <source>Please select your operation</source>
        <translation>请选择您的操作</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="338"/>
        <source>Restore</source>
        <translation>显示</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="339"/>
        <source>Quit</source>
        <translation>退出</translation>
    </message>
</context>
<context>
    <name>cooperation_core::MainWindowPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="62"/>
        <source>Computer</source>
        <translation>电脑协同</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="63"/>
        <source>Phone</source>
        <translation>手机协同</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="74"/>
        <source>Selection of delivery device</source>
        <translation>选择投送设备</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="84"/>
        <location filename="../../src/lib/cooperation/core/gui/win/mainwindow_p_win.cpp" line="126"/>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="88"/>
        <source>Download client</source>
        <translation>客户端下载</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/win/mainwindow_p_win.cpp" line="130"/>
        <source>Download Windows client</source>
        <translation>Windows客户端下载</translation>
    </message>
</context>
<context>
    <name>cooperation_core::NoNetworkWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="150"/>
        <source>Please connect to the network</source>
        <translation>请连接网络</translation>
    </message>
</context>
<context>
    <name>cooperation_core::NoResultTipWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="185"/>
        <source>1. Enable cross-end collaborative applications. Applications on the UOS can be downloaded from the App Store, and applications on the Windows side can be downloaded from: </source>
        <translation>1. 开启跨端协同应用，UOS端应用可在应用商店下载，Windows端下载地址: </translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="199"/>
        <source>2. On the same LAN as the device</source>
        <translation>2. 与本设备在同一局域网</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="204"/>
        <source>3. File Manager-Settings-File Drop-Allow the following users to drop files to me -&quot;Everyone on the same LAN&quot;</source>
        <translation>3. 文件管理器-设置-文件投送-允许以下用户向我投送文件-“同一局域网下的所有人”</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="206"/>
        <source>3. Settings-Basic Settings-Discovery Mode-&quot;Allow everyone in the same LAN&quot;</source>
        <translation>3. 设置-基础设置-可被发现-“允许同一局域网下的所有人”</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="212"/>
        <source>4. Try entering the target device IP in the top search box</source>
        <translation>4. 尝试在顶部搜索框输入目标设备IP</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="216"/>
        <source>Unable to find collaborative device？</source>
        <translation>找不到协同设备？</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="245"/>
        <source>1. The mobile phone needs to download cross end collaborative applications.</source>
        <translation>1.手机需要下载跨端协同应用。</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="246"/>
        <source>Go to download&gt;</source>
        <translation>前往下载&gt;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="250"/>
        <source>2. After installation, scan the code to connect to this device for collaboration.</source>
        <translation>2.安装后，扫描二维码以连接到此设备进行协同。</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="251"/>
        <source>3. After connecting this device, the mobile end needs to keep cross end collaborative applications open and on the same LAN as this device</source>
        <translation>3.连接此设备后，移动端需要保持跨端协同应用程序打开，并与此设备位于同一局域网上</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="253"/>
        <source>Instructions for use</source>
        <translation>使用须知</translation>
    </message>
</context>
<context>
    <name>cooperation_core::NoResultWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="293"/>
        <source>No device found</source>
        <translation>未搜寻到任何设备</translation>
    </message>
</context>
<context>
    <name>cooperation_core::PhoneHelper</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="65"/>
        <source>Disconnect</source>
        <translation>断开</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="93"/>
        <source>“%1”apply to initiate screen casting</source>
        <translation>“%1”请求投屏至本设备</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="95"/>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="212"/>
        <source>cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="96"/>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="157"/>
        <source>comfirm</source>
        <translation>确认</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="139"/>
        <source>“%1”connection disconnected!</source>
        <translation>“%1”连接已断开!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="210"/>
        <source>Are you sure to disconnect and collaborate with &apos;%1&apos;?</source>
        <translation>确定要和 &apos;%1&apos; 断开连接吗?</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="213"/>
        <source>disconnect</source>
        <translation>断开</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ProgressWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="115"/>
        <source>Remaining time %1 | %2%</source>
        <translation>剩余时间 %1 | %2%</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="133"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>cooperation_core::QRCodeWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/phonewidget.cpp" line="102"/>
        <source>Scan code connection</source>
        <translation>扫码连接</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/phonewidget.cpp" line="108"/>
        <source>Please use the cross end collaboration app to scan the code</source>
        <translation>请使用“UOS助手”APP扫码</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/phonewidget.cpp" line="114"/>
        <source>Mobile phones and devices need to be connected to the same local area network</source>
        <translation>手机和设备需要连接同一局域网</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/phonewidget.cpp" line="147"/>
        <source>Click to download UOS assistant APP</source>
        <translation>点击下载UOS助手APP</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ResultWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="179"/>
        <source>Ok</source>
        <comment>button</comment>
        <translation>确定</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="182"/>
        <source>View</source>
        <comment>button</comment>
        <translation>查看</translation>
    </message>
</context>
<context>
    <name>cooperation_core::SettingDialogPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="47"/>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="53"/>
        <source>Everyone in the same LAN</source>
        <translation>同一局域网下的所有人</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="49"/>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="55"/>
        <source>Not allow</source>
        <translation>不允许</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="50"/>
        <source>Screen right</source>
        <translation>屏幕右侧</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="51"/>
        <source>Screen left</source>
        <translation>屏幕左侧</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="54"/>
        <source>Only those who are collaborating are allowed</source>
        <translation>仅允许正在协同的人</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="132"/>
        <source>Basic Settings</source>
        <translation>基础设置</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="143"/>
        <source>Discovery mode</source>
        <translation>可被发现</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="145"/>
        <source>Other devices can discover and connect with you through the &quot;Cooperation&quot; app</source>
        <translation>其他设备可通过“跨端协同”应用发现您，并与您建立连接</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="195"/>
        <source>Device name</source>
        <translation>设备昵称</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="213"/>
        <source>Peripheral share</source>
        <translation>外设共享</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="215"/>
        <source>Allows peripherals that have been established to collaborate across devices to control this device, including keyboard, mouse, trackpad, etc</source>
        <translation>允许已建立跨端协同连接的外设控制此设备，包括键盘、鼠标、触控板等</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="224"/>
        <source>When this device is the connected party, the mouse penetrates from the screen of this device to the position of the connected party</source>
        <translation>当此设备作为连接方时，鼠标从此设备屏幕上穿透到被连接方的位置</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="254"/>
        <source>Connection direction</source>
        <translation>链接方向</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="273"/>
        <source>Allows the following users to send files to me</source>
        <translation>允许以下用户向我投送文件</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="280"/>
        <source>File save location</source>
        <translation>文件保存位置</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="296"/>
        <source>Share clipboard</source>
        <translation>剪切板共享</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="298"/>
        <source>When sharing is enabled on the server (the connected device), the clipboard will be shared between the two computers</source>
        <translation>服务端（被连接的设备）开启共享后，两台电脑之间将共享剪贴板</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="355"/>
        <source>The device name must contain 1 to 20 characters</source>
        <translation>设备昵称必须介于1-20个字符之内</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="362"/>
        <source>The device name must contain 1 to 63 characters</source>
        <translation>设备昵称必须介于1-63个字符之内</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ShareHelper</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="238"/>
        <source>connect</source>
        <translation>连接</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="246"/>
        <source>Disconnect</source>
        <translation>断开</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="263"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="392"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="448"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="458"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="511"/>
        <source>Unable to collaborate to &quot;%1&quot;</source>
        <translation>无法协同至“%1”</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="265"/>
        <source>You are connecting to another device</source>
        <translation>您正在与其他设备进行协同</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="280"/>
        <source>Requesting collaborate to &quot;%1&quot;</source>
        <translation>正在请求协同至“%1”</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="307"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="483"/>
        <source>Coordination with &quot;%1&quot; has ended</source>
        <translation>与“%1”的协同已结束</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="353"/>
        <source>A cross-end collaboration request was received from &quot;%1&quot;</source>
        <translation>接收到“%1”的协同连接请求</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="354"/>
        <source>Reject</source>
        <translation>拒绝</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="355"/>
        <source>Accept</source>
        <translation>接受</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="374"/>
        <source>Cooperation</source>
        <translation>跨端协同</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="393"/>
        <source>Connect to &quot;%1&quot; failed</source>
        <translation>连接到“%1”失败</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="418"/>
        <source>Unable to collaborate</source>
        <translation>无法协同</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="419"/>
        <source>Failed to run process!</source>
        <translation>进程运行失败！</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="441"/>
        <source>Connection successful, coordinating with  &quot;%1&quot;</source>
        <translation>连接成功，正在与“%1”进行协同</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="449"/>
        <source>&quot;%1&quot; has rejected your request for collaboration</source>
        <translation>“%1”已拒绝您的协同请求</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="459"/>
        <source>&quot;%1&quot; is connecting with other devices</source>
        <translation>“%1”正在与其他设备协同</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="503"/>
        <source>The connection request sent to you by &quot;%1&quot; was interrupted due to a timeout</source>
        <translation>“%1”向您发起连接请求因超时中断</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="513"/>
        <source>The other party does not confirm, please try again later</source>
        <translation>对方未确认，请稍后再发起连接</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="524"/>
        <source>The other party has cancelled the connection request !</source>
        <translation>对方取消了连接请求！</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="528"/>
        <source>connect failed</source>
        <translation>连接失败</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="538"/>
        <source>Network not connected, file delivery failed this time.                               Please connect to the network and try again!</source>
        <translation>网络未连接，文件发送失败。   请连接网络并重试！</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="545"/>
        <source>File transfer failed</source>
        <translation>文件传输失败</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="547"/>
        <source>Network not connected, file delivery failed this time.                                           Please connect to the network and try again!</source>
        <translation>络未连接，文件发送失败。请连接网络并重试！</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="562"/>
        <source>Network exception</source>
        <translation>网络异常</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="563"/>
        <source>Please check the network &quot;%1&quot;</source>
        <translation>请检查网络“%1”</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ShareHelperPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="103"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="109"/>
        <source>Cooperation</source>
        <translation>跨端协同</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="200"/>
        <source>Connection successful, coordinating with &quot;%1&quot;</source>
        <translation>连接成功，正在与“%1”进行协同</translation>
    </message>
</context>
<context>
    <name>cooperation_core::TransferHelper</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="433"/>
        <source>Connect to &quot;%1&quot; failed</source>
        <translation>连接到“%1”失败</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="458"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="609"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="683"/>
        <source>File read/write exception</source>
        <translation>文件读写发生异常</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="579"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="630"/>
        <source>The other party has canceled the file transfer</source>
        <translation>对方已取消文件投送</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="478"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="626"/>
        <source>File sent successfully</source>
        <translation>文件投送成功</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="168"/>
        <source>View transfer history</source>
        <translation>查看文件投送记录</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="177"/>
        <source>Send files</source>
        <translation>发送文件</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="302"/>
        <source>The other party did not receive, the files failed to send</source>
        <translation>对方未接收，文件发送失败</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="332"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="335"/>
        <source>File receiving %1% | Remaining time %2</source>
        <translation>文件接收 %1% | 剩余时间 %2</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="342"/>
        <source>Sending files to &quot;%1&quot;</source>
        <translation>正在向“%1”投送文件</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="342"/>
        <source>Receiving files from &quot;%1&quot;</source>
        <translation>接收来自 &quot;%1&quot;的文件</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="399"/>
        <source>Reject</source>
        <translation>拒绝</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="400"/>
        <source>Accept</source>
        <translation>接受</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="401"/>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="394"/>
        <source>&quot;%1&quot; send some files to you</source>
        <translation>“%1”向你发送一封文件</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="313"/>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="412"/>
        <source>The other party has cancelled the transfer request !</source>
        <translation>对方取消了发送请求！</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="452"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="605"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="680"/>
        <source>Insufficient storage space, file delivery failed this time. Please clean up disk space and try again!</source>
        <translation>存储空间不足，文件发送失败。请清理磁盘空间并重试！</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="455"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="607"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="677"/>
        <source>Network not connected, file delivery failed this time. Please connect to the network and try again!</source>
        <translation>网络未连接，文件发送失败。请连接网络并重试！</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="554"/>
        <source>calculating</source>
        <translation>计算中</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="563"/>
        <source>The other party rejects your request</source>
        <translation>对方已拒绝您的请求</translation>
    </message>
</context>
<context>
    <name>cooperation_core::TransferHelperPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="132"/>
        <source>File transfer</source>
        <translation>文件投送</translation>
    </message>
</context>
<context>
    <name>cooperation_core::VncViewer</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/vncviewer.cpp" line="211"/>
        <location filename="../../src/lib/cooperation/core/gui/phone/vncviewer.cpp" line="213"/>
        <source>Disconnected</source>
        <translation>投屏已结束</translation>
    </message>
</context>
<context>
    <name>cooperation_core::WaitConfirmWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="75"/>
        <source>File Transfer</source>
        <translation>文件投送</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="91"/>
        <source>Wait for confirmation...</source>
        <translation>等待对方确认...</translation>
    </message>
</context>
<context>
    <name>cooperation_core::WorkspaceWidgetPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="52"/>
        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="53"/>
        <source>Please enter the device ip/name of the collaborator</source>
        <translation>请输入协同对象的设备IP/昵称</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="56"/>
        <source>Nearby Device</source>
        <translation>附近的设备</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="72"/>
        <source>Re-scan for devices</source>
        <translation>重新寻找设备</translation>
    </message>
</context>
<context>
    <name>cooperation_transfer::TransferHelper</name>
    <message>
        <location filename="../../src/lib/cooperation/transfer/helper/transferhelper.cpp" line="105"/>
        <source>Send files</source>
        <translation>发送文件</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::CooperationMenuScene</name>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/menu/cooperationmenuscene.cpp" line="34"/>
        <source>File transfer</source>
        <translation>文件投送</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::CooperationPlugin</name>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/cooperationplugin.cpp" line="64"/>
        <source>File transfer</source>
        <translation>文件投送</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::FileTransferSettingsDialog</name>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="154"/>
        <source>File transfer settings</source>
        <translation>文件投送设置</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="171"/>
        <source>Everyone in the same LAN</source>
        <translation>同一局域网下的所有人</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="172"/>
        <source>Only those who are collaborating are allowed</source>
        <translation>仅允许正在协同的人</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="173"/>
        <source>Not allow</source>
        <translation>不允许</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="178"/>
        <source>Allows the following users to send files to me</source>
        <translation>允许以下用户向我投送文件</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="179"/>
        <source>File save location</source>
        <translation>文件保存位置</translation>
    </message>
</context>
</TS>